##############################################################################
#
# Copyright (c) 2008 Kapil Thangavelu
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
from zope.viewlet.viewlet import JavaScriptViewlet

YahooBase = JavaScriptViewlet('yui/build/yahoo/yahoo.js')
YahooEvent = JavaScriptViewlet('yui/build/event/event.js')
YahooConnection = JavaScriptViewlet('yui/build/connection/connection.js')
YahooDom = JavaScriptViewlet('yui/build/dom/dom.js')
YahooCore = JavaScriptViewlet('yui/build/yahoo-dom-event/yahoo-dom-event.js')
YahooLogger = JavaScriptViewlet('yui/build/logger/logger-min.js')
YahooElement = JavaScriptViewlet('yui/build/element/element.js')
YahooDataSource = JavaScriptViewlet('yui/build/datasource/datasource.js')
YahooDataTable = JavaScriptViewlet('yui/build/datatable/datatable.js')
YahooTree = JavaScriptViewlet('yui/build/treeview/treeview.js')
YahooSelector = JavaScriptViewlet('yui/build/selector/selector.js')
YahooTabView = JavaScriptViewlet('yui/build/tabview/tabview.js')
